"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

const tslib_1 = require("tslib");

const fs = tslib_1.__importStar(require("fs-extra"));

const resolveFilePathByExts = (exts, resolvePath) => {
  for (let i = 0; i < exts.length; i += 1) {
    const filePath = resolvePath(exts[i]);

    if (fs.existsSync(filePath)) {
      return filePath;
    }
  }

  return '';
};

async function userGlobalRender(api) {
  const appStyleFilePath = resolveFilePathByExts(['css', 'less', 'scss'], ext => api.resolveSrcPath(`app.${ext}`));

  if (appStyleFilePath) {
    const appStyleFilePathSplit = appStyleFilePath.replace(/\\/g, '/').split('/');
    api.addImportToAppEntryFile({
      stage: -10,
      fn: () => `import '@/${appStyleFilePathSplit[appStyleFilePathSplit.length - 1]}';`
    });
  }

  const appFilePath = resolveFilePathByExts(['tsx', 'jsx', 'ts', 'js'], ext => api.resolveSrcPath(`app.${ext}`));

  if (appFilePath) {
    var _await$fs$readFile;

    const appTsxFileContent = (_await$fs$readFile = await fs.readFile(appFilePath)) === null || _await$fs$readFile === void 0 ? void 0 : _await$fs$readFile.toString();

    if (/^export\s(function|const)\srootContainer/gm.test(appTsxFileContent)) {
      api.addImportToAppEntryFile(() => ({
        specifier: '{ rootContainer }',
        source: '@/app'
      }));
      api.addContainerRenderToAppEntryFile({
        stage: 9,
        fn: () => `
    function renderRootContainer(children?: React.ReactElement) {
      return rootContainer(children)
    }`
      });
    }
  }
}

exports.default = userGlobalRender;